summaryrefslogtreecommitdiffstats
path: root/src/gallium/drivers/radeon/AMDIL7XXDevice.h
diff options
context:
space:
mode:
authorTom Stellard <[email protected]>2012-07-30 15:57:50 +0000
committerTom Stellard <[email protected]>2012-07-30 21:10:14 +0000
commit2f921101c0826dc52a2c69f85c3da0f7f6e8212a (patch)
treeb0e58be6d20eee06df83a94571e149d73a401c15 /src/gallium/drivers/radeon/AMDIL7XXDevice.h
parentb72ab79d73b29ec087d90cf2c698adbab4db5def (diff)
radeon/llvm: Rename all AMDIL* classes to AMDGPU*
Diffstat (limited to 'src/gallium/drivers/radeon/AMDIL7XXDevice.h')
-rw-r--r--src/gallium/drivers/radeon/AMDIL7XXDevice.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/src/gallium/drivers/radeon/AMDIL7XXDevice.h b/src/gallium/drivers/radeon/AMDIL7XXDevice.h
index e6c4d8fc664..bf3f82cc26e 100644
--- a/src/gallium/drivers/radeon/AMDIL7XXDevice.h
+++ b/src/gallium/drivers/radeon/AMDIL7XXDevice.h
@@ -25,14 +25,14 @@ class AMDGPUSubtarget;
// 7XX generation of devices and their respective sub classes
//===----------------------------------------------------------------------===//
// The AMDIL7XXDevice class represents the generic 7XX device. All 7XX
// devices are derived from this class. The AMDIL7XX device will only
// support the minimal features that are required to be considered OpenCL 1.0
// compliant and nothing more.
-class AMDIL7XXDevice : public AMDILDevice {
+class AMDGPU7XXDevice : public AMDGPUDevice {
public:
- AMDIL7XXDevice(AMDGPUSubtarget *ST);
- virtual ~AMDIL7XXDevice();
+ AMDGPU7XXDevice(AMDGPUSubtarget *ST);
+ virtual ~AMDGPU7XXDevice();
virtual size_t getMaxLDSSize() const;
virtual size_t getWavefrontSize() const;
virtual uint32_t getGeneration() const;
@@ -43,30 +43,30 @@ public:
protected:
virtual void setCaps();
-}; // AMDIL7XXDevice
+}; // AMDGPU7XXDevice
-// The AMDIL770Device class represents the RV770 chip and it's
+// The AMDGPU770Device class represents the RV770 chip and it's
// derivative cards. The difference between this device and the base
// class is this device device adds support for double precision
// and has a larger wavefront size.
-class AMDIL770Device : public AMDIL7XXDevice {
+class AMDGPU770Device : public AMDGPU7XXDevice {
public:
- AMDIL770Device(AMDGPUSubtarget *ST);
- virtual ~AMDIL770Device();
+ AMDGPU770Device(AMDGPUSubtarget *ST);
+ virtual ~AMDGPU770Device();
virtual size_t getWavefrontSize() const;
private:
virtual void setCaps();
-}; // AMDIL770Device
+}; // AMDGPU770Device
-// The AMDIL710Device class derives from the 7XX base class, but this
+// The AMDGPU710Device class derives from the 7XX base class, but this
// class is a smaller derivative, so we need to overload some of the
// functions in order to correctly specify this information.
-class AMDIL710Device : public AMDIL7XXDevice {
+class AMDGPU710Device : public AMDGPU7XXDevice {
public:
- AMDIL710Device(AMDGPUSubtarget *ST);
- virtual ~AMDIL710Device();
+ AMDGPU710Device(AMDGPUSubtarget *ST);
+ virtual ~AMDGPU710Device();
virtual size_t getWavefrontSize() const;
-}; // AMDIL710Device
+}; // AMDGPU710Device
} // namespace llvm
#endif // _AMDILDEVICEIMPL_H_
@@ -25,14 +25,14 @@ class AMDGPUSubtarget;
// 7XX generation of devices and their respective sub classes
//===----------------------------------------------------------------------===//
-// The AMDIL7XXDevice class represents the generic 7XX device. All 7XX
-// devices are derived from this class. The AMDIL7XX device will only
+// The AMDGPU7XXDevice class represents the generic 7XX device. All 7XX
+// devices are derived from this class. The AMDGPU7XX device will only
// support the minimal features that are required to be considered OpenCL 1.0
// compliant and nothing more.